//
//	aegis - project change supervisor
//	Copyright (C) 2003-2005 Peter Miller;
//	All rights reserved.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
//
// MANIFEST: functions to manipulate filess
//

#include <libaegis/change.h>
#include <aeget/get/change/files.h>
#include <aeget/get/project/files.h>
#include <libaegis/project.h>
#include <common/str_list.h>


void
get_project_files(project_ty *pp, string_ty *filename, string_list_ty *modifier)
{
    change_ty       *cp;

    cp = change_bogus(pp);
    get_change_files(cp, filename, modifier);
    change_free(cp);
}
